@@ -7,7 +7,6 @@ class MCCR():
         self.input = input_cols+un_output_cols
         self.output = output_cols
 
-
     def res(self):
         TE = []
         PTE = []
@@ -25,7 +24,7 @@ class MCCR():
         self.data['PTE'] = PTE
         self.data['SE'] = SE
         self.data['规模报酬分析'] = Type
-        return self.data[self.input+self.output+['TE','PTE','SE','规模报酬分析']]
+        return self.data[[self.data.columns.values[0]]+self.input+self.output+['TE','PTE','SE','规模报酬分析']]
     
     def __CCRmodel(self, i):
         model = Model('CCR')
