@@ -1,6 +1,6 @@
 from deatool.deasolver import Tables
-from PyQt5.QtWidgets import *
-from PyQt5 import QtCore
+from PySide2.QtWidgets import *
+from PySide2 import QtCore
 import sys
 
 def run():
